#! /usr/bin/env python2
"""
***************************************************************************
    filename  : UIchecks.py
    author    : Alessandro Maraschini
    email     : alessandro.maraschini@datamat.it
    copyright : (C) 2003 by DATAMAT
***************************************************************************
//
// $Id: UIchecks.py,v 1.70 2004/11/10 16:07:19 dhsmith Exp $
//
"""


import UIutils
from UIutils import info
from UIutils import errMsg
import os #check conf
import shutil #copyfile
import sys
import time #printHeader
from edg_wl_userinterface_common_AdWrapper import AdWrapper
from edg_wl_userinterface_common_NsWrapper import UserCredential


# String for no default VO
UnspecifiedVO = "unspecified"

"""
 This method returns the current JSUI version
"""
def check_version():
   path=info.prefix
   if path:
      confFile=path+"/etc/edg_wl_ui_cmd_var.conf"
      version= UIutils.parse_file([confFile,"Version"])
      if version[0]:
         return version[1]
   return ""
"""
This Method finds where the UI tools have been installed
"""
def check_prefix():
	sep="/"
	prefix = ""
	confPrefix=""
	found = 0
	env = ""
	#Those files are mandatory for ui-commandline:
	varConf  = "edg_wl_ui_cmd_var.conf"
	errConf = "edg_wl_ui_cmd_err.conf"
	pathList = ['$EDG_WL_LOCATION' , '/opt/edg','/usr/local' , '']
	etcPath = "etc"
	found = 0
	for path in pathList:
		prefix = path
		if path:
			if path[0] == "$":
					#It's an environment path
					try:
						prefix = os.environ[ path[1:] ]
						env= path
					except:
						pass
			if not prefix:
					pass
			# conf prefix points to  $PREFIX/etc
			confPrefix = prefix + sep + etcPath
			#Look for UI configuration files:
			if os.path.isfile(  confPrefix+sep+errConf ):
				if os.path.isfile( confPrefix+sep+varConf ):
					found = 1
					break

	if not found:
		if env:
				errMsg = "Fatal Error: " + env + " environment found but one or more of the following files are missing:\n"
				for file in [varConf, errConf]:
					errMsg = errMsg + file +" "
		else:
				errMsg = "Fatal Error: Unable to find userinterface configuration files"
		print errMsg
		sys.exit(1)
	info.prefix= prefix
	"""
	Parse UI Error configuration file
	"""
	try:
		f=open( confPrefix + sep +"edg_wl_ui_cmd_err.conf"  ,'r' )
		line=f.readline().strip()
		while line:
			line=line.strip()
			try:
				tag , ver = line.split("=")
				if tag.strip()=="UI_VERSION":
					UIutils.info.version = ver
					break
			except:
					pass
			line=f.readline()
		f.close()
		if UIutils.info.version =="":
				raise AttributeError
	except:
		print "Fatal Error: Unable find Version attribute in Ui  configuration file: \n" + confPrefix + sep +"edg_wl_ui_cmd_err.conf"
		sys.exit(1)

	"""
	Parse UI variable configuration file
	"""
	ad = AdWrapper(1)
	info.confFile = confPrefix + sep +varConf
	if not os.path.isfile (info.confFile ):
		errMsg = "Fatal Error: Unable to find UI  default configuration file:\n " + info.confFile
		print errMsg
		sys.exit(1)
	ad.fromFile ( info.confFile )
	err, apiMsg = ad.get_error()
	if err:
		errMsg = "Fatal Error: Unable to parse UI default configuration file:\n " + info.confFile+".\n" + apiMsg
		print errMsg
		sys.exit(1)
	info.confAd = ad
	return prefix


"""
This method parses the command-line option
args  - option typed byt he user (typically sys.args[1:])
short - string made of chars. A semicolon (:) indicates that the previous option has to retreive an additional parameter
        this options have to be typed preceded by "-" in the command line
long  - list made of string. An equal char at the end of the string indicates that this option has to retreive an additional parameter
        this options have to be typed preceded by "--" in the command line
"""
def checkOpt(arg , short , long):
   #Make a deep copy of the arg
   args =[]
   for i in arg:
      args.append(i)
   #Pre-Processing param: help and version
   for preOpt in ["--help", "--version"]:
      if  preOpt in args:
          return [0,[preOpt],[], [] ]
   optNul = []
   optPar  = []
   #SHORT options check
   while (short):
      next=""
      #take the option letter and check
      opt=short[0]
      short=short[1:]
      if short:
         #cut the letter
         next=short[0]
      if (opt <"a") or (opt>"z"):
         return [   1,[],[],[]   ]
      if next==":":
         #option required
         short=short[1:]
         optPar.append("-" + opt)
      else:
         #option not required
         optNul.append("-" + opt)
   #LONG options check
   for opt in long:
      if opt[-1] == "=" :
         #option required
         optPar.append("--"+opt[:-1])
      else:
         optNul.append("--" + opt)
   options = []  #list of options required
   value   = []  #list of values typed for each required option
   extra   = []  #list of extra parameters found
   error   = []
   repeated   = []  #list of options repeated
   missing    = []     #list of options specified without required par
   unknown    = []  #list of unknown options
   sysExit=0
   while (args):
      next=""
      short="---"
      #get the item on the list
      opt=args.pop(0)
      if opt.startswith("-"):
         #it's an option
         if (opt.startswith("--")) and (len(opt)>2):
            short=opt[1:3]
         if (len(opt)>2) and opt[1]!="-":
            opt="-"+opt
         if args:
            next=args[0]
            if next.startswith("-"):
               #It's an option, not a value
               next=""
         #check if option repeated
         #if (opt in options) or (short in options):
         #check if option allowed
         if opt in  optNul: #option without par
             options.append(opt)
             value.append("")
         elif opt in optPar: #option with par
            if next: #syntax OK
               options.append(opt)
               value.append(next)
               args=args[1:]
            else:    #syntax error: required parameter
               missing.append(opt)
               sysExit=1
               break
         else:
            unknown.append(opt)
            sysExit=1
            break
      else:
         #Extra option typed: no-more option allowed
         if args:
            next=args[0]
            if next.startswith("-"):
               #It's an option, not allowed after an extra
               error.append(next)
               args=args[1:]
               sysExit=1
               break
         extra.append(opt)
      #check for item value (required??) AND (if required .... is present???)
   for rep in  repeated:
      errMsg('Error','UI_REPEATED_OPT',rep)
   for mis in missing:
       errMsg('Error','UI_ARG_MISS',mis)
   for un in unknown:
       errMsg('Error','UI_WRONG_OPT', un)
   for err in error:
       errMsg('Error','UI_OPT_POS',err)
   return sysExit, options, value, extra

"""
configuration file prioritiy:
0).	(high priority)	DefaultVoName (from proxy certificate)
1) 	--config or --vo option (exclusive)
2) 	environment variable
3) 	VirtualOrganisation attribute specified in JDL (if submit or list match)
4) 	default value (from UI config file)
"""
def checkConfVo(conf , virtualOrg, *jobad):
    if conf and virtualOrg:
        # those options   cannot match togheter
        errMsg('Warning', "UI_ARG_EXCLUSIVE" , "--config-vo", "--vo")
        UIutils.exit(1)
    #JobAd init
    if jobad:
        jobad=jobad[0]
    #This point to the final conf file
    """
    Look for the Virtual Organisation file
    """
    final = ""
    confDir=""
    sep = "/"
    voDefaultName = "edg_wl_ui.conf"
    voName =""
    #When parsing VO files if no defaultVo has been found then prompt an Error Message (otherwise warning)
    voErrMsg ="Error"
    """
    Retrieving Default VirtualOrganisation from existing Certificate
    """
    defaultVo = ""
    vomsrc=""
    if jobad:
         jobadHasKey = jobad.hasKey("VirtualOrganisation")
    else:
         jobadHasKey=0

    #   ENV var init
    try:
        env = os.environ['EDG_WL_UI_CONFIG_VO']
    except:
        env = ""
    try:
        proxy_file_name = os.environ['X509_USER_PROXY']
    except:
        proxy_file_name = '/tmp/x509up_u'+ repr(os.getuid())
    if os.path.isfile(proxy_file_name):
	#Try to look up the default Vo in a previous existing proxy
	uc = UserCredential( proxy_file_name  )
	defaultVo = uc.getDefaultVoName()

    """
    Cross-check For Options
    """
    # --vo option specified
    if virtualOrg:
		voName =  virtualOrg
		confDir = UIutils.info.prefix + sep + "etc" + sep +voName.lower()
		final = confDir +  sep + voDefaultName
		vomsrc = "--vo option"
    #   --configVo option specified
    elif conf:
		final = conf
		vomsrc = "--config-vo option"
    elif env:
		final = env
		vomsrc = "EDG_WL_UI_CONFIG_VO env variable"
    #   VirtualOrganisation attribute specified in JDL file
    elif jobad and jobadHasKey:
	voName = jobad.getStringValue("VirtualOrganisation" )[0]

	confDir = UIutils.info.prefix + sep + "etc" + sep +voName.lower()
	final = confDir +  sep + voDefaultName
	vomsrc="JDL"
    # DefaultVo attribute specified in configuration file
    elif info.confAd.hasKey("DefaultVo"):
		VoFromConf = info.confAd.getStringValue("DefaultVo")[0]
		if (not defaultVo) and (VoFromConf != UnspecifiedVO):
			voName = VoFromConf
			confDir = UIutils.info.prefix + sep + "etc" + sep + voName.lower()
			final = confDir +  sep + voDefaultName
			vomsrc = "UI conf file"

    #default Vo is returned by a voms proxy certificate
    if defaultVo:
		voErrMsg = "Warning"
		defaultConfDir= UIutils.info.prefix + sep + "etc" + sep +defaultVo.lower()
		defaultConfFile = defaultConfDir +sep + voDefaultName
    """
    VO File check and parsing
    """
    if final:
		err , voName , ad = parseVo (voName , confDir , final , voErrMsg )
		# Override message prompt to user only if:
		# Vo has been specified somehow (vomsrc)
		# defaultVo has been found (defaultVo)
		# VO name is different from DefaultVo (voName!=defaultVo)
		if  (vomsrc ) and (defaultVo ) and ( voName!=defaultVo ):
			errMsg('Warning', "UI_VOMS_OVERRIDE" , vomsrc , defaultVo )
			if UIutils.info.noint:
					UIutils.exit(0)
			else:
				question = "Do you want to continue?"
				answ = UIutils.questionYN(question)
				if not answ: #NO answered
					print "bye"
					UIutils.exit(0)
			# Specified Vo differs from Default one: parse Defatult Vo
			vomsrc = "proxy certificate extension"
			final = defaultConfFile
			err , voName , ad = parseVo (defaultVo , defaultConfDir , defaultConfFile , "Error" )
			if err:
				UIutils.exit(1)
    elif defaultVo:
		vomsrc = "proxy certificate extension"
		final = defaultConfFile
		err , voName , ad = parseVo ( defaultVo , defaultConfDir , defaultConfFile , "Error" )
		if err:
			UIutils.exit(1)
    """
    Final Check
    """
    if not voName:
		# Unable to find any vo
		errMsg( "Error"  , "UI_NO_VOMS" , "Unable to determine a valid user's VO" )
		UIutils.exit(1)
    else:
	# VO properly found somewherehow
	info.confAdVo  = ad
	msg = "Selected Virtual Organisation name (from "+ vomsrc+ "): "+ voName
	if UIutils.info.debug:
		msg = "#### Debug Message ####\n" + msg +"\nVOMS configuration file successfully loaded:\n" \
		+ final + info.confAdVo.toLines() +  "\n#### End Debug ####\n"
	#Print VOMS message
	UIutils.print_message( UIutils.info.logFile,   msg )
	# Cohexistence between properties and VO
	if jobad:
		if jobad.hasKey("VirtualOrganisation"):
			jobad.removeAttribute ("VirtualOrganisation")
		jobad.setAttributeStr ("VirtualOrganisation" , voName)

"""
This Method is used by checkConfVo
it parses the file and prompt for info
Definite VO Configuration file name found: check for file properties:
- Existence
- Ad parsing
- Semantic cohexistence between file name/path and VO file attribute ( if present )
- Semantic cohexistence between file properties and (if specified) JDL VO attribute
"""
def parseVo( voName , confDir , final , eMsg ):
	# Look for configuration Vo file
	if confDir:
		if not os.path.isdir( confDir ):
			errMsg(eMsg,'UI_NO_VO_CONF_INFO', voName )
			return [1,0,0]
	if not os.path.isfile( final ):
			errMsg(eMsg,'UI_FILE_NOT_FOUND', final )
			return [1,0,0]
	# Parsing Ad VO file
	ad = AdWrapper(1)
	if ad.fromFile ( final):
		errMsg(eMsg , "UI_JDL_ADD_ERROR", "Unable to parse Vo conf file (not a valid classad):\n " +final )
		return [1,0,0]
	#The VirtualOrganisation Attribute must match with the specified voName
	val = ad.getStringValue ( "VirtualOrganisation")
	if val:
		val = val[0]
		if voName:
			if val!=voName:
				errMsg(eMsg,'UI_JDL_VO_MATCH', voName , val ,final )
				return [1,0,0]
		return [0, val , ad ]
	else:
		errMsg(eMsg,'UI_JDL_AD_ERROR', ad.get_error() )
		return [1,0,0]

"""
                 checkConf
 This Method check the existence of the Group file
 if not found then tries to find the default cfg file
 it returns a list as follows:
 [1, <configure file>] if not found
 [0, <configure file>] on success

 Config file looking for priority:
  1)	--config <file>       option
  2)	'EDG_WL_UI_CONFIG_VAR'    environment variable
  3)	default configuration file (   <prefix>/etc/edg_wl_ui_cmd_var.conf   )

"""
def checkConf( conf , logPath ):
  #This point to the final conf file
  sys_exit= 0
  final = ""
  #   ENV var:
  try:
    env = os.environ['EDG_WL_UI_CONFIG_VAR']
  except:
    env = ""
  #   --config found
  if conf:
     final = conf
  #   Env found
  elif env:
    final = env
  # Do Nothing, keeps with default one (already set???) TBD CHECK
  else:
    pass
  if final:
     # conf file has to be changed from default one
     if not os.path.isfile( final ):
        print "Fatal Error: config file not found:\n"+os.path.abspath(final)
        sys.exit (1)
     else:
        ad = AdWrapper(1)
        if ad.fromFile ( final):
           print "Fatal Error: Unable to parse config file:\n " + os.path.abspath(final)
           sys.exit (1)
        info.confAd  = ad
        info.confFile = os.path.abspath( final )
        if info.debug:
           print "####\nConfiguration file loaded:" , final ,ad.toLines()

  if logPath:
     logFile = os.path.abspath (logPath)
     if os.path.isfile ( logFile):
         try:
           os.remove(logFile)
         except:
           errMsg ( "Warning" , "UI_RM_FILE", logFile )
  else :
        logFile = UIutils.create_err_log ( info.prgname )

  # Rename the old logFile with the new value (if needed)
  if info.logFile:
   if info.logFile != logFile:
     try:
       shutil.copyfile( info.logFile, logFile  )
     except:
       errMsg('Error','UI_WRITE_FILE' , logFile   )
       UIutils.exit(1)
     try:
       os.remove(info.logFile)
     except:
       errMsg("Warning",'UI_RM_FILE' , info.logFile   )
     info.logFile = logFile




"""
def check_outFile(out_file,*submit)
check The specified output file target
"""
def check_outFile(out_file,*submit):
  TBremoved=0
  out_file=os.path.abspath(out_file)
  sind=out_file.rfind('/')
  if not os.path.isdir(out_file[:sind]): #the path doesn't exist
          UIutils.errMsg("Warning","UI_DIR_NOT_FOUND",out_file[:sind])
          return [1,out_file,1]
  if os.path.isfile(out_file): #the file already exists
    TBremoved=1
    if submit:
       f=open(out_file)
       line=f.readline()
       line = line.strip()
       f.close()
       if line == "###Submitted Job Ids###":
           return [0,out_file,0]
    UIutils.errMsg("Warning","UI_FILE_EXISTS",out_file)
    if info.noint: #No-int active
       UIutils.errMsg("Warning","UI_SKIP_QUESTION","overwriting the File "+out_file)
       return [1,out_file,1] #the file will be removed
    else:
       question="Do you want to overwrite?"
       answ=UIutils.questionYN(question)
       print ""
       if not answ: #NO answered
           print "bye"
           return [0,"",0]
  #if submit: #The file won't be removed
  #     TBremoved=1
  info.outFile = out_file
  return [0,out_file,TBremoved]



#############
#This method checks the user proxy certificate
#and if necessary creates it
#############
def check_proxy(*valid) :
	if valid:
		valid=valid[0]
		hours, minutes  = valid.split(":")
		secondsLeft = int(hours)*60*60 + int(minutes)*60
	file_path_sep = '/'
	uid = os.getuid()
	pid = os.getpid()
	proxy_file_name = ''
	INST = info.prefix
	if not INST:
		exit(1)
	"""
	#checking the grid-proxy bin files directory
	GSI_DIR = ''
	try:
		GSI_DIR = os.environ['GSI_INSTALL_PATH']
	except:
		pass
	try:
		GSI_DIR = os.environ['GLOBUS_INSTALL_PATH']
	except:
		pass
	try:
		GSI_DIR = os.environ['GLOBUS_LOCATION']
	except:
		pass
	#None of the searched environment variables is set
	if not GSI_DIR:
		errMsg('Error','UI_ENVIRONM_MISSING','GLOBUS_LOCATION')
		return 1

	# Search for grid-proxy-init executable
	Grid_Proxy_Tool = ''
	Grid_Proxy_Tool = GSI_DIR + file_path_sep + 'bin'
	command = Grid_Proxy_Tool + file_path_sep + 'grid-proxy-init'
	if not os.path.isfile(command):
		errMsg('Error','UI_FILE_NOT_FOUND',command)
		return 1
	"""
	#Initialize proxy certificate file name
	try:
		proxy_file_name = os.environ['X509_USER_PROXY']
	except:
		proxy_file_name = '/tmp/x509up_u'+repr(uid)
	#Check if Proxy certificate already exists
	#voms =  info.confAdVo.getStringValue("VirtualOrganisation")[0]
	if os.path.isfile(proxy_file_name):
		#Retrieve Proxy Information ( new Approach )
		uc = UserCredential (proxy_file_name)
		timeleft = uc.getExpiration()  - int( time.time() ) + 3600*time.daylight
		info.issuer =uc.getIssuer()

		"""
		OLD APPROACH:
		gsi_tmp_file = file_path_sep + 'tmp' + file_path_sep + 'gsi-tmp-file_' + repr(pid) + "_" + repr(uid) + "_" + repr (time.time() )
		###################################
		#The Proxy File Already Exists
		###################################
		exefile = Grid_Proxy_Tool + file_path_sep + 'grid-proxy-info'
		if os.path.isfile(exefile):
				command = exefile + ' -timeleft>' + gsi_tmp_file
				retcode = os.system(command)
				if retcode:
					if os.path.isfile(exefile):
						os.remove(gsi_tmp_file)
					errMsg('Error','UI_CAN_NOT_EXECUTE',command)
					return 1
		else:
				#grid-proxy-info executable not avaliable
				errMsg('Error','UI_FILE_NOT_FOUND',exefile)
				return 1
		f = open(gsi_tmp_file)
		try:
				timeleft = int (f.readline())
				print "Proxy Time Left read with proxy-info :" , time.ctime(  timeleft  )
		except:
				errMsg('Warning','UI_READ_FILE',command)
				f.close()
				os.remove(gsi_tmp_file)
				return 1
		f.close()
		os.remove(gsi_tmp_file)
		"""
		if not valid:
			# timeleft should be at least 20 minutes
			secondsLeft = 20*60
			valid = "00:20"
		if timeleft>secondsLeft:
			return checkVomsExtension(proxy_file_name)
		elif timeleft>0:
			errMsg("Error",'UI_PROXY_DURATION' , valid )
			return 1
		else:
			errMsg("Error",'UI_PROXY_EXPIRED' )
			return 1

	else:
		# The Proxy Does not exist
		errMsg("Error",'UI_PROXY_NOT_FOUND')
		return 1

	"""
	###################################
	The Proxy Must be (re)CREATED    <<<<---  DEPRECATED!!!
	###################################


	if valid:
			valid = " -valid " + valid
	else:
		valid = "" #Using idefault 12-hours proxy duration
	#Proxy Certificate creation:
	if info.noint:
		errMsg('Error', 'UI_PROXY_CREATION_NOINT')
		return 1
	elif vomsrc.find("--")!=0:
		if not UIutils.questionYN("Do you wish to continue?"):
			print "bye"
			UIutils.exit(0)


	#VOMS Implementation
	#EDG-VOMS-proxy-init

	try:
		VOMS_DIR = os.environ['EDG_LOCATION']
	except:
		errMsg('Error','UI_ENVIRONM_MISSING','EDG_LOCATION')
		return 1

	vomsArg = " -voms " + voms
	exefile = VOMS_DIR + file_path_sep +"bin"+ file_path_sep +  'edg-voms-proxy-init'
	command =VOMS_DIR + file_path_sep +"bin"+ file_path_sep +  'edg-voms-proxy-init' +  valid + vomsArg


	#OLD Implementation: GRID-proxy-init
	#exefile = Grid_Proxy_Tool + file_path_sep + 'grid-proxy-init'
	#command = Grid_Proxy_Tool + file_path_sep + 'grid-proxy-init' + valid

	if os.path.isfile(exefile):
		#Create a proxy certificate
		retcode  = os.system(command)
		if retcode!=0:
			errMsg ('Error','UI_PROXY_INIT_ERROR')
			return 1
		else:
			#Proxy certificate created
			errMsg('Success',"UI_PROXY_CREATED")
			return checkVomsExtension(proxy_file_name)
	else:
		#edg-voms-proxy-init executable not found
		errMsg('Error','UI_FILE_NOT_FOUND',exefile)
		return 1
	"""

"""
Look fot the VOMS (This method is called bt Check_proxy)
"""
def checkVomsExtension ( proxyfile ):
	from edg_wl_userinterface_common_NsWrapper import UserCredential
	uc = UserCredential(proxyfile)
	"""
	Retrieve vomses from proxy and check whether it is contained
	"""
	vomses = uc.getVoNames()
	if not vomses:
	   if UIutils.info.debug:
		# No voms in certificate: print error
		errMsg( 'Warning' , "UI_NO_VOMS", uc.get_error() )
	   return 0
	return 0

"""
Checks for native external API
"""
def checkError (apiName , inst, exit = 0):
  err , apiMsg = inst.get_error ()
  if err==0:
    return err
  elif err==1:
     #ERROR
     errMsg ( "Error" , "API_NATIVE_ERROR" , apiName  , apiMsg )
     if exit:
        UIutils.exit (1)
  else:
     #WARNING
     errMsg ( "Warning" , "API_NATIVE_ERROR" , apiName  , apiMsg )
  return err

  
"""
check and parse values passed with "--from" and "--to" options
"""
def checkFromTo ( fromT , toT):
	parsed =[]
	now = time.time()
	opt = "--from"
	for val in [fromT , toT]:
		if val:
			h = m = "00"
			M = time.strftime("%m")
			D = time.strftime("%d")
			Y = time.strftime("%Y")
			seps = val.split(":")
			l = len (seps)
			if l ==2:
				h, m = seps
			elif l ==4:
				M,D,h,m = seps
			elif l ==5:
				M ,D ,h, m ,Y = seps
			else:
				errMsg ( "Error" , "UI_ARG_MISMATCH" , opt   )
				return []
			if len(Y)==2:
				#Adjust Year value (if needed)
				try:
					Y=int(Y)
				except:
					errMsg ( "Error" , "UI_ARG_MISMATCH" , opt  )
					return []
				currentY = time.localtime()[0] +1
				if Y>currentY%100:
					Y =Y -100
				Y= str( (currentY/100*100)  + Y )
			#Checking values lengths
			if len(h)!=2 or len(m)!=2 or len(M)!=2 or len(D)!=2 or len(Y)!=4:
				errMsg ( "Error" , "UI_ARG_MISMATCH" , opt )
				return []
			finalString = M + D + h +  m + Y
			formatString = "%m%d%H%M%Y"
			try:
				parsed.append(   time.timezone +  int (time.mktime(  time.strptime( finalString  , formatString)  )   )  )
			except ValueError:
				errMsg ( "Error" , "UI_ARG_MISMATCH" , opt )
				return []
			if parsed[-1]>now:
				errMsg ( "Error" , "UI_ARG_OUT_OF_LIMIT" , opt )
				return []
			opt="--to"
		else:
			parsed.append( 0 )
	if (parsed[0]>=parsed[1]) and parsed[1]:
		errMsg ( "Error" , "UI_ARG_OUT_OF_LIMIT" , "--from" )
		return []
	return parsed



"""
This Method inizializes the ouput variables
checking wheter -noint option has been set or not
"""
def check_noint(argv):
  set=0
  #There is the following set cases
  if  ("--debug" in argv) or("-debug" in argv):
    set=1
    info.debug=1
    info.logFile=UIutils.create_err_log(info.prgname)
  if ("--noint" in argv ) or ("-noint" in argv ):
    set=2
    info.noint = 1
    info.logFile=UIutils.create_err_log( info.prgname)
  else:
    print "" #Write an empty line
  if ( ("--nomsg" in argv) or ("-nomsg" in argv) ):
#     if output=="edg-job-submit":
     if info.prgname=="edg-job-submit":
        set=3
        info.logFile=UIutils.create_err_log(info.prgname)
  #Redirect the error/debug logFile into a specified path
  if  ("--logfile" in argv) or ("-logfile" in argv):
       info.setLog=1
       info.logFile=UIutils.create_err_log(info.prgname)
       set= 1
  if set>0:  #Could be debug, noint or nomsg (submit)
       #Print Information program inside the file
       printHeader(argv)

"""
This method is used by check_noint
This Method Prints the Header in the Log File
"""
def printHeader( argv):
    message="*****************************\n"
    message= message + time.asctime(time.gmtime(time.time()))
    message= message +"\n\nFunction Called:"
    message= message + "\n"+argv[0]
    message= message +"\n\nOptions specified:"
    for i in range (1,len(argv)):
      if (    (argv[i-1])[0]!="-"  ) or  (   (argv[i])[0]=="-"    )  :
         message= message +"\n"
      message= message +argv[i]+"   "
    message = message + "\n*****************************"
    message = message + "\n---No Errors found---"
    if info.logFile:
      try:
         f=open(  info.logFile ,'w')
         f.write(message + "\n")
      except:
	logFile = info.logFile
	info.logFile = ""
	errMsg('Error','UI_WRITE_FILE',   logFile )
	sys.exit(1)


def unknown( ad  ):
	unknown=""
	known = ["requirements","fuzzyrank","nodenumber","listenerport","jobsteps","currentstep","rank", \
	"submitto","executable","stdoutput","stdinput","stderror","arguments","myproxyserver","jobtype","outputse", \
        "type","virtualorganisation","hlrlocation","outputsandbox","inputsandbox","environment","inputdata","replicacatalog", \
	"outputdata","dataaccessprotocol","retrycount","edg_jobid", "lrms_type", "mwversion"]
	for att in ad.attributes():
		if not att.lower() in known:
			unknown+="- " + att +"\n"
	if unknown:
		errMsg ( "Warning" , "UI_JDL_UNKNOWN" , unknown )



#check_proxy()


"""
for proxy_file_name in [ '/tmp/x509up_u502']:
	if os.path.isfile(proxy_file_name):
		print "Checking " +proxy_file_name
		uc = UserCredential( proxy_file_name  )
		print "Vo names: "  , uc.getVoNames()
		print "Error? " , uc.get_error () ;
		print "Expiration" , uc.getExpiration()
		print "Error? " , uc.get_error () ;
		print "Issuer?" , uc.getIssuer()
		print "Error? " , uc.get_error () ;
		#print "Default Vo name" , uc.getDefaultVoName()
		#print "Error? " , uc.get_error () ;
"""


"""
from edg_wl_userinterface_common_LbWrapper import Status
st=Status()
print "Performing Query"

#  queryStates:
	# string host , int port ,
	# const std::vector<std::string>& tagNames,const std::vector<std::string>& tagValues,
	# string issuer,
	# int from , int to
	#int ad
x = st.queryStates ("ibm139.cnaf.infn.it", 9000 , \
[] ,[] , \
"/C=IT/O=INFN/OU=Personal Certificate/L=DATAMAT DSAGRD/CN=Alessandro Maraschini/Email=alessandro.maraschini@datamat.it", \
0,0,1)
print "result = " , x
if x==0:
	print st.get_error()
"""
"""
from edg_wl_userinterface_common_LbWrapper import Eve
ev=Eve()
print "\n\nPerforming Query Events"

#  Event:
	# string host , int port ,
	# const std::vector<std::string>& tagNames,const std::vector<std::string>& tagValues,
	# string issuer,
	# int from , int to
x = ev.queryEvents("ibm139.cnaf.infn.it", 9000 , \
[] ,[] , \
"/C=IT/O=INFN/OU=Personal Certificate/L=DATAMAT DSAGRD/CN=Alessandro Maraschini/Email=alessandro.maraschini@datamat.it", \
0,0)
print "result = " , x
if x==0:
	print st.get_error()
"""

"""
print "CHECK FROM: "
a, b = checkFromTo( sys.argv[1] ,sys.argv[2] )
"""
